=====================
 zope.authentication
=====================

.. image:: https://img.shields.io/pypi/v/zope.authentication.svg
        :target: https://pypi.org/project/zope.authentication/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.authentication.svg
        :target: https://pypi.org/project/zope.authentication/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.authentication.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.authentication

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.authentication/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.authentication?branch=master

.. image:: https://readthedocs.org/projects/zopeauthentication/badge/?version=latest
        :target: https://zopeauthentication.readthedocs.io/en/latest/
        :alt: Documentation Status

This package provides a definition of authentication concepts for use in
Zope Framework. This includes:

- ``IAuthentication``
- ``IUnauthenticatedPrincipal``
- ``ILogout``

Documentation is hosted at https://zopeauthentication.readthedocs.io/en/latest/
